# -*- coding: utf-8 -*-

from rest_framework import serializers

from .. import models


class OrganizationFormSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationForm
        fields = '__all__'


class OrganizationFormSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationFormSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationTypeSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationType
        fields = '__all__'


class OrganizationTypeSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationTypeSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationAddressSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationAddress
        fields = '__all__'


class OrganizationAddressSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationAddressSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationSerializer(serializers.ModelSerializer):
    status_name = serializers.SerializerMethodField()
    organization_type = OrganizationTypeSerializer(read_only=True)
    organization_form = OrganizationFormSerializer(read_only=True)

    class Meta:
        model = models.Organization
        fields = '__all__'

    def get_status_name(self, obj):
        return obj.get_status_display()


class OrganizationSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        

class OwnerOrganizationSerializer(OrganizationSerializer):
    class Meta:
        model = models.OwnerOrganization
        fields = '__all__'


class OwnerOrganizationSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OwnerOrganizationSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class CustomerOrganizationSerializer(OrganizationSerializer):

    class Meta:
        model = models.CustomerOrganization
        fields = '__all__'


class CustomerOrganizationSerializerCreate(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator')


class CustomerOrganizationSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.CustomerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
        read_only_fields = ('code',)


class SupplierOrganizationSerializer(OrganizationSerializer):
    class Meta:
        model = models.SupplierOrganization
        fields = '__all__'


class SupplierOrganizationSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.SupplierOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class SupplierOrganizationSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.SupplierOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class VectorOrganizationSerializer(OrganizationSerializer):
    class Meta:
        model = models.VectorOrganization
        fields = '__all__'


class VectorOrganizationSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.VectorOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class VectorOrganizationSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.VectorOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationGroupSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationGroup
        fields = '__all__'


class OrganizationGroupSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationGroup
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OrganizationGroupSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.OrganizationGroup
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

        
class FieldSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Field
        fields = '__all__'


class FieldSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Field
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class FieldSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Field
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class ContactRoleSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.ContactRole
        fields = '__all__'


class ContactRoleSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class ContactRoleSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class ContactTitleSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.ContactTitle
        fields = '__all__'


class ContactTitleSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class ContactTitleSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class ContactSerializer(serializers.ModelSerializer):
    status_name = serializers.SerializerMethodField()
    organization = OrganizationSerializer(read_only=True)
    title = ContactTitleSerializer(read_only=True)
    role = ContactRoleSerializer(read_only=True)

    class Meta:
        model = models.Contact
        fields = '__all__'

    def get_status_name(self, obj):
        return obj.get_status_display()


class ContactSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class ContactSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class OwnerContactSerializer(ContactSerializer, serializers.ModelSerializer):
    class Meta:
        model = models.OwnerContact
        fields = '__all__'


class OwnerContactSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class OwnerContactSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class CustomerContactSerializer(ContactSerializer, serializers.ModelSerializer):
    class Meta:
        model = models.CustomerContact
        fields = '__all__'


class CustomerContactSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.CustomerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class CustomerContactSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.CustomerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class SupplierContactSerializer(ContactSerializer, serializers.ModelSerializer):
    class Meta:
        model = models.SupplierContact
        fields = '__all__'


class SupplierContactSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.SupplierContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class SupplierContactSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.SupplierContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class WorkerContactSerializer(ContactSerializer, serializers.ModelSerializer):
    class Meta:
        model = models.WorkerContact
        fields = '__all__'


class WorkerContactSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.WorkerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class WorkerContactSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.WorkerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        
        
class VectorContactSerializer(ContactSerializer, serializers.ModelSerializer):
    class Meta:
        model = models.VectorContact
        fields = '__all__'


class VectorContactSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.VectorContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class VectorContactSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.VectorContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')